@@ -24,27 +24,27 @@ def split_version(v):
     return vs
 
 def gensio_version_ge(v):
-    """Return True if the version v is >= the gensio version, false if not"""
+    """Return True if the gensio version is >= version v, False if not"""
     try:
         gv = gensio.version
     except Exception as E:
-        return False
+        return True # Versions with a version macro are older than we care about
 
     gvs = split_version(gv)
     vs = split_version(v)
-    if vs[0] < gvs[0]:
+    if int(vs[0]) < int(gvs[0]):
         return True
-    if vs[0] > gvs[0]:
+    if int(vs[0]) > int(gvs[0]):
         return False
-    if vs[1] < gvs[1]:
+    if int(vs[1]) < int(gvs[1]):
         return True
-    if vs[1] > gvs[1]:
+    if int(vs[1]) > int(gvs[1]):
         return False
-    if vs[2] > gvs[2]:
+    if int(vs[2]) < int(gvs[2]):
         return True
-    if vs[2] > gvs[2]:
+    if int(vs[2]) > int(gvs[2]):
         return False
-    return vs[3] < gvs[3]
+    return vs[3] <= gvs[3]
 
 class Logger:
     def gensio_log(self, level, log):
